@@ -9,6 +9,7 @@ qemu_functions = {}
 enums = {} # { enumType: { enumConstant: enumValue } }
 lxc_enums = {} # { enumType: { enumConstant: enumValue } }
 qemu_enums = {} # { enumType: { enumConstant: enumValue } }
+event_ids = []
 
 import os
 import sys
@@ -219,6 +220,9 @@ def lxc_function(name, desc, ret, args, file, module, cond):
 def enum(type, name, value):
     if type not in enums:
         enums[type] = {}
+    if (name.startswith('VIR_DOMAIN_EVENT_ID_') or
+        name.startswith('VIR_NETWORK_EVENT_ID_')):
+        event_ids.append(name)
     if value == 'VIR_TYPED_PARAM_INT':
         value = 1
     elif value == 'VIR_TYPED_PARAM_UINT':
@@ -910,10 +914,10 @@ def buildStubs(module, api_xml):
     wrapper_file = "build/%s.c" % module
 
     include = open(header_file, "w")
-    include.write("/* Generated */\n\n")
+    include.write("/* Generated by generator.py */\n\n")
 
     export = open(export_file, "w")
-    export.write("/* Generated */\n\n")
+    export.write("/* Generated by generator.py */\n\n")
 
     wrapper = open(wrapper_file, "w")
     wrapper.write("/* Generated by generator.py */\n\n")
@@ -943,6 +947,10 @@ def buildStubs(module, api_xml):
         # Write C pointer conversion functions.
         for classname in primary_classes:
             print_c_pointer(classname, wrapper, export, include)
+        # Write define wrappers around event id enums, so that the
+        # preprocessor can see which enums were available.
+        for event_id in event_ids:
+            include.write("#define %s %s\n" % (event_id, event_id))
 
     include.close()
     export.close()
